[][src]Function ffmpeg_dev::sys::av_add_index_entry

pub unsafe extern "C" fn av_add_index_entry(
    st: *mut AVStream,
    pos: i64,
    timestamp: i64,
    size: c_int,
    distance: c_int,
    flags: c_int
) -> c_int

Add an index entry into a sorted list. Update the entry if the list already contains it.

@param timestamp timestamp in the time base of the given stream