pub unsafe extern "C" fn av_format_get_probe_score(
s: *const AVFormatContext,
) -> c_intExpand description
Accessors for some AVFormatContext fields. These used to be provided for ABI compatibility, and do not need to be used anymore.
pub unsafe extern "C" fn av_format_get_probe_score(
s: *const AVFormatContext,
) -> c_intAccessors for some AVFormatContext fields. These used to be provided for ABI compatibility, and do not need to be used anymore.