pub unsafe extern "C" fn av_get_pix_fmt_name(
pix_fmt: AVPixelFormat,
) -> *const c_charExpand description
Return the short name for a pixel format, NULL in case pix_fmt is unknown.
@see av_get_pix_fmt(), av_get_pix_fmt_string()
pub unsafe extern "C" fn av_get_pix_fmt_name(
pix_fmt: AVPixelFormat,
) -> *const c_charReturn the short name for a pixel format, NULL in case pix_fmt is unknown.
@see av_get_pix_fmt(), av_get_pix_fmt_string()