[−][src]Function ffmpeg_dev::sys::av_iformat_next
pub unsafe extern "C" fn av_iformat_next(
f: *const AVInputFormat
) -> *mut AVInputFormat
If f is NULL, returns the first registered input format, if f is non-NULL, returns the next registered input format after f or NULL if f is the last one.