[−][src]Function ffmpeg_dev::sys::av_opt_set_dict_val
pub unsafe extern "C" fn av_opt_set_dict_val(
obj: *mut c_void,
name: *const c_char,
val: *const AVDictionary,
search_flags: c_int
) -> c_int
@note Any old dictionary present is discarded and replaced with a copy of the new one. The caller still owns val is and responsible for freeing it.