[][src]Function ffmpeg_dev::sys::av_stream_get_end_pts

pub unsafe extern "C" fn av_stream_get_end_pts(st: *const AVStream) -> i64

Returns the pts of the last muxed packet + its duration

the retuned value is undefined when used with a demuxer.