pub unsafe extern "C" fn av_stream_get_r_frame_rate(
s: *const AVStream,
) -> AVRationalExpand description
Accessors for some AVStream fields. These used to be provided for ABI compatibility, and do not need to be used anymore.
pub unsafe extern "C" fn av_stream_get_r_frame_rate(
s: *const AVStream,
) -> AVRationalAccessors for some AVStream fields. These used to be provided for ABI compatibility, and do not need to be used anymore.