pub unsafe extern "C" fn ff_all_channel_counts() -> *mut AVFilterChannelLayoutsExpand description
Construct an AVFilterChannelLayouts coding for any channel layout, with known or unknown disposition.
pub unsafe extern "C" fn ff_all_channel_counts() -> *mut AVFilterChannelLayoutsConstruct an AVFilterChannelLayouts coding for any channel layout, with known or unknown disposition.