[−][src]Function ffmpeg_dev::sys::ff_get_v_length
pub unsafe extern "C" fn ff_get_v_length(val: u64) -> c_int
Get the length in bytes which is needed to store val as v.
pub unsafe extern "C" fn ff_get_v_length(val: u64) -> c_int
Get the length in bytes which is needed to store val as v.