Function ffio_ensure_seekback

pub unsafe extern "C" fn ffio_ensure_seekback(
    s: *mut AVIOContext,
    buf_size: i64,
) -> c_int
Ensures that the requested seekback buffer size will be available

Will ensure that when reading sequentially up to buf_size, seeking within the current pos and pos+buf_size is possible. Once the stream position moves outside this window this guarantee is lost.