[−][src]Function ffmpeg_dev::sys::avio_find_protocol_name
pub unsafe extern "C" fn avio_find_protocol_name(
url: *const c_char
) -> *const c_char
Return the name of the protocol that will handle the passed URL.
NULL is returned if no protocol could be found for the given URL.
@return Name of the protocol or NULL.