pub unsafe extern "C" fn ff_read_line_to_bprint(
s: *mut AVIOContext,
bp: *mut AVBPrint,
) -> i64Expand description
Read a whole line of text from AVIOContext to an AVBPrint buffer. Stop reading after reaching a \r, a \n, a \r\n, a \0 or EOF. The line ending characters are NOT included in the buffer, but they are skipped on the input.
@param s the read-only AVIOContext @param bp the AVBPrint buffer @return the length of the read line, not including the line endings, negative on error.