pub unsafe extern "C" fn ff_reshuffle_raw_rgb(
s: *mut AVFormatContext,
ppkt: *mut *mut AVPacket,
par: *mut AVCodecParameters,
expected_stride: c_int,
) -> c_intExpand description
Reshuffles the lines to use the user specified stride.
@param ppkt input and output packet @return negative error code or 0 if no new packet was allocated non-zero if a new packet was allocated and ppkt has to be freed CONTAINS_PAL if in addition to a new packet the old contained a palette